summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2021-12-11 21:09:39 +0000
committerCaolán McNamara <caolanm@redhat.com>2021-12-12 13:35:00 +0100
commitafa35742a4633db31b6d6c72cf45741506e9edfb (patch)
tree10fb0b0116ddf6fcc2ee34c9baa39b1ec0103a83 /include
parent569de88e9c7eda964252518282d26a8f7d059718 (diff)
prefer more css::awt::XPopupMenu api
Change-Id: Ib008281d63071ea79935af83cbe434be66155455 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/126692 Tested-by: Jenkins Reviewed-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'include')
-rw-r--r--include/framework/actiontriggerhelper.hxx11
-rw-r--r--include/sfx2/viewsh.hxx4
2 files changed, 7 insertions, 8 deletions
diff --git a/include/sfx2/viewsh.hxx b/include/sfx2/viewsh.hxx
index 2971c210ea59..54d962450e8f 100644
--- a/include/sfx2/viewsh.hxx
+++ b/include/sfx2/viewsh.hxx
@@ -53,7 +53,6 @@ class SfxModule;
class SfxViewFrame;
class Printer;
class SfxPrinter;
-class Menu;
class NotifyEvent;
class SfxInPlaceClient;
class SfxLokCallbackInterface;
@@ -299,7 +298,8 @@ public:
void SetController( SfxBaseController* pController );
css::uno::Reference<css::frame::XController> GetController() const;
- bool TryContextMenuInterception(const Menu& rIn, const OUString& rMenuIdentifier,
+ bool TryContextMenuInterception(const css::uno::Reference<css::awt::XPopupMenu>& rIn,
+ const OUString& rMenuIdentifier,
css::uno::Reference<css::awt::XPopupMenu>& rOut,
css::ui::ContextMenuExecuteEvent aEvent);
bool TryContextMenuInterception(const css::uno::Reference<css::awt::XPopupMenu>&,
diff --git a/include/framework/actiontriggerhelper.hxx b/include/framework/actiontriggerhelper.hxx
index 227535648950..d0efa7a3a39b 100644
--- a/include/framework/actiontriggerhelper.hxx
+++ b/include/framework/actiontriggerhelper.hxx
@@ -24,7 +24,6 @@
namespace com::sun::star::awt { class XPopupMenu; }
namespace com::sun::star::container { class XIndexContainer; }
-class Menu;
namespace framework
{
@@ -45,20 +44,20 @@ namespace framework
// to optimize the time of creation of a menu from an actiontrigger structure.
// IMPORTANT: The caller must ensure that the menu pointer is valid through the
// life time of the XIndexContainer object!!!
// @param pNewMenu = Must be a valid menu. Please be aware that this implementation is based on
// the above mentioned restriction!!!
static css::uno::Reference< css::container::XIndexContainer > CreateActionTriggerContainerFromMenu(
- const Menu* pMenu, const OUString* pMenuIdentifier );
+ const css::uno::Reference<css::awt::XPopupMenu>& rMenu, const OUString* pMenuIdentifier );
// Fills the submitted rActionTriggerContainer with the structure of the menu
// provided as the second parameter
// @param rActionTriggerContainer = must be an instance of service "com.sun.star.ui.ActionTriggerContainer"
// @param pNewMenu = must be a valid menu
static void
FillActionTriggerContainerFromMenu(
css::uno::Reference< css::container::XIndexContainer > const & rActionTriggerContainer,
- const Menu* pMenu );
+ const css::uno::Reference<css::awt::XPopupMenu>& rMenu);
};
}
@@ -45,20 +44,20 @@ namespace framework
// IMPORTANT: The caller must ensure that the menu pointer is valid through the
// life time of the XIndexContainer object!!!
- // @param pNewMenu = Must be a valid menu. Please be aware that this implementation is based on
- // the above mentioned restriction!!!
+ // @param rMenu = Must be a valid menu. Please be aware that this implementation is based on
+ // the above mentioned restriction!!!
static css::uno::Reference< css::container::XIndexContainer > CreateActionTriggerContainerFromMenu(
@@ -45,20 +44,20 @@ namespace framework
// provided as the second parameter
// @param rActionTriggerContainer = must be an instance of service "com.sun.star.ui.ActionTriggerContainer"
- // @param pNewMenu = must be a valid menu
+ // @param rMenu = must be a valid menu
static void
FillActionTriggerContainerFromMenu(